@@ -1,5 +1,5 @@
 /***************************************
-  $Header: /cvsroot/petscgraphics/cahnhill.c,v 1.6 2002/01/15 23:13:05 hazelsct Exp $
+  $Header: /cvsroot/petscgraphics/cahnhill.c,v 1.8 2003/05/21 22:52:29 hazelsct Exp $
 
   This file contains the heart of the Cahn-Hilliard formulation, in particular
   the functions which build the finite difference residuals and Jacobian.
@@ -22,7 +22,7 @@
   +html+ <i>m</i>; if <i>m</i>&gt;0
   then the 0 phase is stable and vice versa.
 
-  inline PetscScalar ch_psiprime It returns the derivative itself.
+  PetscScalar ch_psiprime It returns the derivative itself.
 
   PetscScalar C The concentration.
 
@@ -40,10 +40,10 @@ static inline PetscScalar ch_psiprime (PetscScalar C, PetscScalar mparam)
 /*++++++++++++++++++++++++++++++++++++++
   This calculates the second derivative of homogeneous free energy with respect
   to concentration, for insertion into the Jacobian matrix.  See the
-  +latex+{\tt ch\_psiprime} function for the definition of $\Psi$.
-  +html+ <tt>ch_psiprime</tt> function for the definition of Psi.
+  +latex+{\tt ch\_psiprime()} function for the definition of $\Psi$.
+  +html+ <tt>ch_psiprime()</tt> function for the definition of Psi.
 
-  inline PetscScalar ch_psidoubleprime It returns the second derivative
+  PetscScalar ch_psidoubleprime It returns the second derivative
   +latex+$\Psi''(C)$.
   -latex-Psi''(C).
 
@@ -68,56 +68,56 @@ static inline PetscScalar ch_psidoubleprime (PetscScalar C, PetscScalar mparam)
   +html+ <i>y</i>-direction, ``down'' to negative <i>y</i>, ``left'' to
   +html+ negative <i>x</i> and ``right'' to positive <i>x</i>.
 
-inline PetscScalar ch_residual_2d Returns the residual itself
+  PetscScalar ch_residual_2d Returns the residual itself
 
-PetscScalar *conc Array of concentrations
+  PetscScalar *conc Array of concentrations
 
-PetscScalar alpha Model parameter
-+latex+$\kappa\alpha$
--latex-kappa alpha
+  PetscScalar alpha Model parameter
+  +latex+$\kappa\alpha$
+  -latex-kappa alpha
 
-PetscScalar beta Model parameter
-+latex+$\kappa\beta$
--latex-kappa beta
+  PetscScalar beta Model parameter
+  +latex+$\kappa\beta$
+  -latex-kappa beta
 
-PetscScalar mparam Model parameter
-+latex+$m$
--latex-m
+  PetscScalar mparam Model parameter
+  +latex+$m$
+  -latex-m
 
-PetscScalar hx Inverse square
-+latex+$x$-spacing $h_x^{-2}$
-+html+ <i>x</i>-spacing <i>h<sub>x</sub></i><sup>-2</sup>
+  PetscScalar hx Inverse square
+  +latex+$x$-spacing $h_x^{-2}$
+  +html+ <i>x</i>-spacing <i>h<sub>x</sub></i><sup>-2</sup>
 
-PetscScalar hy Inverse square
-+latex+$y$-spacing $h_y^{-2}$
-+html+ <i>y</i>-spacing <i>h<sub>y</sub></i><sup>-2</sup>
+  PetscScalar hy Inverse square
+  +latex+$y$-spacing $h_y^{-2}$
+  +html+ <i>y</i>-spacing <i>h<sub>y</sub></i><sup>-2</sup>
 
-int upup Index to array position two cells up from current
+  int upup Index to array position two cells up from current
 
-int upleft Index to array position one cell up and one left from current
+  int upleft Index to array position one cell up and one left from current
 
-int up Index to array position one cell up from current
+  int up Index to array position one cell up from current
 
-int upright Index to array position one cell up and one right from current
+  int upright Index to array position one cell up and one right from current
 
-int leftleft Index to array position two cells left of current
+  int leftleft Index to array position two cells left of current
 
-int left Index to array position one cell left of current
+  int left Index to array position one cell left of current
 
-int current Index to current cell array position
+  int current Index to current cell array position
 
-int right Index to array position one cell right of current
+  int right Index to array position one cell right of current
 
-int rightright Index to array position two cells right of current
+  int rightright Index to array position two cells right of current
 
-int downleft Index to array position one cell down and one left from current
+  int downleft Index to array position one cell down and one left from current
 
-int down Index to array position one cell down from current
+  int down Index to array position one cell down from current
 
-int downright Index to array position one cell down and one right from current
+  int downright Index to array position one cell down and one right from current
 
-int downdown Index to array position two cells down from current
-++++++++++++++++++++++++++++++++++++++*/
+  int downdown Index to array position two cells down from current
+  ++++++++++++++++++++++++++++++++++++++*/
 
 static inline PetscScalar ch_residual_2d
 (PetscScalar *conc, PetscScalar alpha, PetscScalar beta, PetscScalar mparam,
@@ -166,84 +166,84 @@ static inline PetscScalar ch_residual_2d
   +html+ <i>y</i>, ``down'' to negative <i>y</i>, ``left'' to
   +html+ negative <i>x</i> and ``right'' to positive <i>x</i>.
 
-inline PetscScalar ch_residual_3d Returns the residual itself
+  PetscScalar ch_residual_3d Returns the residual itself
 
-PetscScalar *conc Array of concentrations
+  PetscScalar *conc Array of concentrations
 
-PetscScalar alpha Model parameter
-+latex+$\kappa\alpha$
--latex-kappa alpha
+  PetscScalar alpha Model parameter
+  +latex+$\kappa\alpha$
+  -latex-kappa alpha
 
-PetscScalar beta Model parameter
-+latex+$\kappa\beta$
--latex-kappa beta
+  PetscScalar beta Model parameter
+  +latex+$\kappa\beta$
+  -latex-kappa beta
 
-PetscScalar mparam Model parameter
-+latex+$m$
--latex-m
+  PetscScalar mparam Model parameter
+  +latex+$m$
+  -latex-m
 
-PetscScalar hx Inverse square
-+latex+$x$-spacing $h_x^{-2}$
-+html+ <i>x</i>-spacing <i>h<sub>x</sub></i><sup>-2</sup>
+  PetscScalar hx Inverse square
+  +latex+$x$-spacing $h_x^{-2}$
+  +html+ <i>x</i>-spacing <i>h<sub>x</sub></i><sup>-2</sup>
 
-PetscScalar hy Inverse square
-+latex+$y$-spacing $h_y^{-2}$
-+html+ <i>y</i>-spacing <i>h<sub>y</sub></i><sup>-2</sup>
+  PetscScalar hy Inverse square
+  +latex+$y$-spacing $h_y^{-2}$
+  +html+ <i>y</i>-spacing <i>h<sub>y</sub></i><sup>-2</sup>
 
-PetscScalar hz Inverse square
-+latex+$z$-spacing $h_z^{-2}$
-+html+ <i>z</i>-spacing <i>h<sub>z</sub></i><sup>-2</sup>
+  PetscScalar hz Inverse square
+  +latex+$z$-spacing $h_z^{-2}$
+  +html+ <i>z</i>-spacing <i>h<sub>z</sub></i><sup>-2</sup>
 
-int frontfront Index to array position two cells in front of current
+  int frontfront Index to array position two cells in front of current
 
-int frontup Index to array position one cell front and one up from current
+  int frontup Index to array position one cell front and one up from current
 
-int frontleft Index to array position one cell front and one left from current
+  int frontleft Index to array position one cell front and one left from current
 
-int front Index to array position one cell in front of current
+  int front Index to array position one cell in front of current
 
-int frontright Index to array position one cell front and one right from current
+  int frontright Index to array position one cell front and one right from current
 
-int frontdown Index to array position one cell front and one down from current
+  int frontdown Index to array position one cell front and one down from current
 
-int upup Index to array position two cells up from current
+  int upup Index to array position two cells up from current
 
-int upleft Index to array position one cell up and one left from current
+  int upleft Index to array position one cell up and one left from current
 
-int up Index to array position one cell up from current
+  int up Index to array position one cell up from current
 
-int upright Index to array position one cell up and one right from current
+  int upright Index to array position one cell up and one right from current
 
-int leftleft Index to array position two cells left of current
+  int leftleft Index to array position two cells left of current
 
-int left Index to array position one cell left of current
+  int left Index to array position one cell left of current
 
-int current Index to current cell array position
+  int current Index to current cell array position
 
-int right Index to array position one cell right of current
+  int right Index to array position one cell right of current
 
-int rightright Index to array position two cells right of current
+  int rightright Index to array position two cells right of current
 
-int downleft Index to array position one cell down and one left from current
+  int downleft Index to array position one cell down and one left from current
 
-int down Index to array position one cell down from current
+  int down Index to array position one cell down from current
 
-int downright Index to array position one cell down and one right from current
+  int downright Index to array position one cell down and one right from current
 
-int downdown Index to array position two cells down from current
+  int downdown Index to array position two cells down from current
 
-int backup Index to array position one cell back and one up from current
+  int backup Index to array position one cell back and one up from current
 
-int backleft Index to array position one cell back and one left from current
+  int backleft Index to array position one cell back and one left from current
 
-int back Index to array position one cell in back of current
+  int back Index to array position one cell in back of current
 
-int backright Index to array position one cell back and one right from current
+  int backright Index to array position one cell back and one right from current
 
-int backdown Index to array position one cell back and one down from current
+  int backdown Index to array position one cell back and one down from current
 
-int backback Index to array position two cells in back of current
-++++++++++++++++++++++++++++++++++++++*/
+  int backback Index to array position two cells in back of current
+  ++++++++++++++++++++++++++++++++++++++*/
 
 static inline PetscScalar ch_residual_3d
 (PetscScalar *conc, PetscScalar alpha, PetscScalar beta, PetscScalar mparam,
@@ -1525,11 +1525,9 @@ int ch_jacobian_alpha_2d (AppCtx *user)
   ierr = MatAssemblyBegin(user->alpha,MAT_FINAL_ASSEMBLY); CHKERRQ (ierr);
   ierr = MatAssemblyEnd(user->alpha,MAT_FINAL_ASSEMBLY); CHKERRQ (ierr);
 
-  /* Make J a copy of alpha with the same local mapping. */
+  /* Make J a copy of alpha with the same local mapping (setting new mapping is
+     unnecessary with PETSc 2.1.5). */
   ierr = MatDuplicate (user->alpha, MAT_COPY_VALUES, &(user->J)); CHKERRQ (ierr);
-  ierr = MatSetLocalToGlobalMapping (user->J, user->isltog); CHKERRQ (ierr);
-
-  /* ierr = MatView (user->J, VIEWER_STDOUT_SELF); CHKERRQ (ierr); */
 
   /* Tell the matrix we will never add a new nonzero location to the
      matrix. If we do, it will generate an error. */
@@ -1649,11 +1647,9 @@ int ch_jacobian_alpha_3d (AppCtx *user)
   ierr = MatAssemblyBegin(user->alpha,MAT_FINAL_ASSEMBLY); CHKERRQ (ierr);
   ierr = MatAssemblyEnd(user->alpha,MAT_FINAL_ASSEMBLY); CHKERRQ (ierr);
 
-  /* Make J a copy of alpha with the same local mapping. */
+  /* Make J a copy of alpha with the same local mapping (setting new mapping is
+     unnecessary with PETSc 2.1.5). */
   ierr = MatDuplicate (user->alpha, MAT_COPY_VALUES, &(user->J)); CHKERRQ (ierr);
-  ierr = MatSetLocalToGlobalMapping (user->J, user->isltog); CHKERRQ (ierr);
-
-  /* ierr = MatView (user->J, VIEWER_STDOUT_SELF); CHKERRQ (ierr); */
 
   /* Tell the matrix we will never add a new nonzero location to the
      matrix. If we do, it will generate an error. */
