@@ -1,5 +1,5 @@
 /***************************************
-  $Header: /cvsroot/petscgraphics/illuminator.h,v 1.22 2004/08/17 15:05:42 hazelsct Exp $
+  $Header: /cvsroot/petscgraphics/illuminator.h,v 1.27 2004/11/04 22:47:45 hazelsct Exp $
 
   This is the interface for the Illuminator library.
 ***************************************/
@@ -17,19 +17,19 @@
   +*/
 typedef enum {
   /*+Scalar field.+*/
-  FIELD_SCALAR                    = 0x00,
+  FIELD_SCALAR           = 0x00,
   /*+Ternary composition field with two components (third component is inferred
     from first two).+*/
-  FIELD_TERNARY                   = 0x10,
+  FIELD_TERNARY          = 0x10,
   /*+Vector field.+*/
-  FIELD_VECTOR                    = 0x20,
+  FIELD_VECTOR           = 0x20,
   /*+Full ds*ds tensor field, e.g. transformation.+*/
-  FIELD_TENSOR_FULL               = 0x30,
+  FIELD_TENSOR_FULL      = 0x30,
   /*+Symmetric tensor field (using lines in principal stress directions).+*/
-  FIELD_TENSOR_SYMMETRIC          = 0x38,
-  /*+Symmetric tensor field, inferring last diagonal from the opposite of the
-    sum of the others.+*/
-  FIELD_TENSOR_SYMMETRIC_ZERODIAG = 0x39
+  FIELD_TENSOR_SYMMETRIC = 0x38,
+  /*+Shear tensor field, both symmetric and inferring last diagonal from the
+    opposite of the sum of the others.+*/
+  FIELD_TENSOR_SHEAR     = 0x39
 } field_plot_type;
 
 /* Core stuff in illuminator.c */
@@ -43,6 +43,9 @@ int IllDraw3DBlock
  int n_quants, PetscScalar *isoquants, PetscScalar *colors);
 
 /* Utility stuff in utility.c */
+int auto_scale
+(PetscScalar *global_array, int points, int num_fields, int display_field,
+ field_plot_type fieldtype, int dimensions, PetscScalar *scale);
 int minmax_scale
 (PetscScalar *global_array, int points, int num_fields, int display_field,
  field_plot_type fieldtype, int dimensions, PetscScalar *minmax);
@@ -73,8 +76,10 @@ static inline int DATriangulateLocal
 int IllErrorHandler (int id, char *message);
 
 /* Plotting functions to render data into an RGB buffer */
+int render_scale_2d (guchar *rgb, int rwidth, int rheight, int bytes_per_pixel,
+		     field_plot_type fieldtype, int symmetry);
 int render_rgb_local_2d
-(guchar *rgb, int rwidth, int rheight, int bytes_per_pixel,
+(guchar *rgb, int rwidth, int rheight, int rowskip, int bytes_per_pixel,
  PetscScalar *global_array, int num_fields, int display_field,
  field_plot_type fieldtype, PetscScalar *minmax, int nx,int ny, int xs,int ys,
  int xm,int ym);
@@ -110,4 +115,14 @@ int GeomviewEnd (MPI_Comm comm);
 int GeomviewDisplayTriangulation (MPI_Comm comm, PetscScalar *minmax,
 				  char *name, PetscTruth transparent);
 
+/* Imlib2 stuff */
+#ifdef IMLIB2_EXISTS
+#include <X11/Xlib.h>
+#include <Imlib2.h>
+int imlib2_render_triangles (DATA32 *data, int width, int height,
+			     int num_triangles, int *triangle_coords,
+			     PetscScalar *triangle_colors, int color_skip,
+			     PetscScalar *triangle_shades, int shade_skip);
+#endif
+
 #endif /* ILLUMINATOR_H */
